@@ -111,9 +111,24 @@ dlg_ask_password__common (FrWindow       *window,
 	data->window = window;
 	data->pwd_type = pwd_type;
 
-	/* Get the widgets. */
+	/* Make the widgets. */
+
+	data->dialog = g_object_new (GTK_TYPE_DIALOG,
+				     "transient-for", GTK_WINDOW (window),
+				     "modal", TRUE,
+				     "use-header-bar", _gtk_settings_get_dialogs_use_header (),
+				     NULL);
+	gtk_container_add (GTK_CONTAINER (gtk_dialog_get_content_area (GTK_DIALOG (data->dialog))),
+			   GET_WIDGET ("password_vbox"));
+	gtk_dialog_add_buttons (GTK_DIALOG (data->dialog),
+				_GTK_LABEL_CANCEL, GTK_RESPONSE_CANCEL,
+				_("_OK"), GTK_RESPONSE_OK,
+				NULL);
+	gtk_dialog_set_default_response (GTK_DIALOG (data->dialog),
+					 GTK_RESPONSE_OK);
+	gtk_style_context_add_class (gtk_widget_get_style_context (gtk_dialog_get_widget_for_response (GTK_DIALOG (data->dialog), GTK_RESPONSE_OK)),
+				     GTK_STYLE_CLASS_SUGGESTED_ACTION);
 
-	data->dialog = GET_WIDGET ("password_dialog");
 	data->password_entry = GET_WIDGET ("password_entry");
 
 	/* Set widgets data. */
