@@ -1422,6 +1422,26 @@ _g_key_file_get_string_list (GKeyFile    *key_file,
 }
 
 
+/* GSettings utils */
+
+
+GSettings *
+_g_settings_new_if_schema_installed (const char *schema_id)
+{
+	GSettingsSchema *schema;
+
+	schema = g_settings_schema_source_lookup (g_settings_schema_source_get_default (),
+						  schema_id,
+						  TRUE);
+	if (schema == NULL)
+		return NULL;
+
+	g_settings_schema_unref (schema);
+
+	return g_settings_new (schema_id);
+}
+
+
 /* line parser */
 
 
